@@ -54,28 +54,3 @@ def define_data(loc: Path) -> dict:
             result.update(extract)
 
     return result
-
-
-def decode_decisions(loc: Path, context: str) -> Optional[Iterator[dict]]:
-    """Given folder name, generate decision-like data from subfolders
-
-    Args:
-        loc (Path): The parent local directory
-        context (str): Either "legacy" or "sc"
-
-    Returns:
-        Optional[Iterator[dict]]: [description]
-
-    Yields:
-        Iterator[Optional[Iterator[dict]]]: [description]
-    """
-    if context not in ["legacy", "sc"]:
-        return None
-
-    folder = loc / "decisions" / context
-    if not folder.exists():
-        return None
-
-    locations = folder.glob("*")
-    for location in locations:
-        yield define_data(location)
