@@ -105,11 +105,20 @@ def process_units(nodes: list[dict]) -> None:
     """
     for node in nodes:
         if node.get("item", None):
-            node["item"] = uniform_section_label(node["item"])
+            # deal with items where the input is an integer
+            # only strings can be matched in the `uniform_section_label` function
+            converted = str(node["item"])
+
+            # for SEC., # SECTION text, convert to uniform "Section"
+            node["item"] = uniform_section_label(converted)
+
+            # ensure that item text is sound, 500 as arbitrary number check
             if len(node["item"]) > 500:
                 node["item"] = node["item"][:500]
 
         if caption := node.get("caption", None):
+
+            # ensure that caption text is sound, 500 as arbitrary number check
             if len(node["caption"]) > 500:
                 node["caption"] = caption[:500]
 
@@ -221,12 +230,15 @@ def load_statute(loc: Path) -> Optional[dict]:
     if not (data := get_details(loc)):
         print(f"No details.yaml file: {loc}.")
         return None
+    print(f"Details found: {loc}.")
 
     legacy_file = get_legacy_file(loc, data["category"])
     if legacy_file.exists():
         data["units"] = get_sections(legacy_file)
+        print(f"Provisions found: {loc}.")
         return data
     else:
+        print(f"Provisions found: {loc}.")
         return add_units(loc, data)
 
 
@@ -258,21 +270,21 @@ def get_directory(
 def get_title(category: str, num: str) -> Optional[str]:
     category_text = None
     if category.lower() == "ra":
-        return f"Republic Act No. {num}"
+        return f"Republic Act No. {num.upper()}"
     elif category.lower() == "eo":
-        return f"Executive Order No. {num}"
+        return f"Executive Order No. {num.upper()}"
     elif category.lower() == "pd":
-        return f"Presidential Decree No. {num}"
+        return f"Presidential Decree No. {num.upper()}"
     elif category.lower() == "bp":
-        return f"Batas Pambansa Blg. {num}"
+        return f"Batas Pambansa Blg. {num.upper()}"
     elif category.lower() == "ca":
-        return f"Commonwealth Act No. {num}"
+        return f"Commonwealth Act No. {num.upper()}"
     elif category.lower() == "act":
-        return f"Act No. {num}"
+        return f"Act No. {num.upper()}"
     elif category.lower() == "bm":
-        return f"Bar Matter No. {num}"
+        return f"Bar Matter No. {num.upper()}"
     elif category.lower() == "am":
-        return f"Administrative Matter No. {num}"
+        return f"Administrative Matter No. {num.upper()}"
     elif category.lower() == "roc":
         return f"{num} Rules of Court"
     elif category.lower() == "res":
@@ -283,6 +295,8 @@ def get_title(category: str, num: str) -> Optional[str]:
         return f"{num} Constitution"
     elif category.lower() == "es":
         return f"Spanish {num}"
+    elif category.lower() == "veto":
+        return f"Veto Message of Republic Act No. {num}"
     return None
 
 
